@@ -53,11 +53,13 @@ class Pypale:
 
     def valid_token(self, return_token: str = None, return_email: str = None) -> bool:
         if return_token is None:
-            raise ValueError("return_token was not specified")
+            logging.exception(msg="pypale: return_token was not specified")
+            return False
         try:
             decoded_return_token = base64.b64decode(return_token).decode(self.ENCODING)
-        except binascii.Error as e:
-            raise ValueError(str(e))
+        except binascii.Error:
+            logging.exception(msg="pypale: could not b64decode return token")
+            return False
         token_metadata = jwt.decode(
             decoded_return_token, self.secret_key, algorithms=[self.JWT_ALGORITHM]
         )
